@@ -39,7 +39,7 @@ G_BEGIN_DECLS
 			    GnomeVolumeControlPreferencesClass))
 #define GNOME_VOLUME_CONTROL_IS_PREFERENCES(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_VOLUME_CONTROL_TYPE_PREFERENCES))
-#define GNOME_VOLUME_CONTROL_IS_PREFERENCES_CLASS(obj) \
+#define GNOME_VOLUME_CONTROL_IS_PREFERENCES_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_VOLUME_CONTROL_TYPE_PREFERENCES))
 
 typedef struct _GnomeVolumeControlPreferences {
@@ -50,6 +50,7 @@ typedef struct _GnomeVolumeControlPreferences {
 
   /* gconf client inherited from our parent */
   GConfClient *client;
+  guint client_cnxn;
 
   /* treeview inside us */
   GtkWidget *treeview;
@@ -68,8 +69,7 @@ void	gnome_volume_control_preferences_change	(GnomeVolumeControlPreferences *pre
 /*
  * GConf thingy. Escapes spaces and such.
  */
-gchar *	get_gconf_key	(GstMixer *mixer,
-			 gchar    *track_label);
+gchar *	get_gconf_key	(GstMixer *mixer, GstMixerTrack *track);
 
 
 G_END_DECLS
