@@ -97,6 +97,7 @@ cb_option_changed (GtkComboBox *box,
     model = gtk_combo_box_get_model (box);
     gtk_tree_model_get (model, &iter, 0, &opt, -1);
     gst_mixer_set_option (ctrl->mixer, GST_MIXER_OPTIONS (ctrl->track), opt);
+    g_free (opt);
   }
 }
 
@@ -505,25 +506,29 @@ gnome_volume_control_track_show (GnomeVolumeControlTrack *track,
     if (track->options) {
       gtk_table_set_row_spacing (track->table,
 				 track->pos, 6);
-      gtk_table_set_row_spacing (track->table,
-				 track->pos - 1, 6);
+      if (track->pos > 0)
+        gtk_table_set_row_spacing (track->table,
+				   track->pos - 1, 6);
     } else if (!track->toggle) {
       gtk_table_set_col_spacing (track->table,
 				 track->pos, 6);
-      gtk_table_set_col_spacing (track->table,
-				 track->pos - 1, 6);
+      if (track->pos > 0)
+        gtk_table_set_col_spacing (track->table,
+				   track->pos - 1, 6);
     }
   } else {
     if (track->options) {
       gtk_table_set_row_spacing (track->table,
 				 track->pos, 0);
-      gtk_table_set_row_spacing (track->table,
-				 track->pos - 1, 0);
+      if (track->pos > 0)
+        gtk_table_set_row_spacing (track->table,
+				   track->pos - 1, 0);
     } else if (!track->toggle) {
       gtk_table_set_col_spacing (track->table,
 				 track->pos, 0);
-      gtk_table_set_col_spacing (track->table,
-				 track->pos - 1, 0);
+      if (track->pos > 0)
+        gtk_table_set_col_spacing (track->table,
+				   track->pos - 1, 0);
     }
   }
 }
