@@ -41,7 +41,7 @@ G_BEGIN_DECLS
 			    GnomeVolumeControlWindowClass))
 #define GNOME_VOLUME_CONTROL_IS_WINDOW(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_VOLUME_CONTROL_TYPE_WINDOW))
-#define GNOME_VOLUME_CONTROL_IS_WINDOW_CLASS(obj) \
+#define GNOME_VOLUME_CONTROL_IS_WINDOW_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_VOLUME_CONTROL_TYPE_WINDOW))
 
 typedef struct _GnomeVolumeControlWindow {
