@@ -74,8 +74,8 @@ GSTPPipelineDescription audiosink_pipelines[] = {
 #endif
   {PIPE_TYPE_AUDIOSINK, 0, "OSS - Open Sound System",
       "osssink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, TRUE},
-  {PIPE_TYPE_AUDIOSINK, 0, "Polypaudio Sound Server",
-      "polypsink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
+  {PIPE_TYPE_AUDIOSINK, 0, "Pulse - PulseAudio Sound Server",
+      "pulsesink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
   {PIPE_TYPE_AUDIOSINK, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_SUPPLIED,
       audiosink_test_pipe, TRUE}
 };
@@ -121,7 +121,7 @@ GSTPPipelineDescription audiosrc_pipelines[] = {
 #endif
   {PIPE_TYPE_AUDIOSRC, 0, "OSS - Open Sound System", "osssrc", FALSE,
       TEST_PIPE_AUDIOSINK, NULL, FALSE},
-  {PIPE_TYPE_AUDIOSRC, 0, "Polypaudio Sound Server", "polypsrc", FALSE,
+  {PIPE_TYPE_AUDIOSRC, 0, "Pulse - PulseAudio Sound Server", "pulsesrc", FALSE,
       TEST_PIPE_AUDIOSINK, NULL, FALSE},
   /* Note: using triangle instead of sine for test sound so we
    * can test the vorbis encoder as well (otherwise it'd compress too well) */
